@@ -2,7 +2,7 @@ from django.template.loader import render_to_string
 from django.template import TemplateDoesNotExist
 
 
-class UIWidget(object):
+class Widget(object):
     def __init__(self):
         pass
 
@@ -10,8 +10,7 @@ class UIWidget(object):
         raise NotImplementedError()
 
 
-
-class TemplateWidget(UIWidget):
+class TemplateWidget(Widget):
     template_name = None
     context = None
 
@@ -24,8 +23,9 @@ class TemplateWidget(UIWidget):
         if not self.template_name:
             raise TemplateDoesNotExist('Template name cannot be None')
 
-        return render_to_string(self.template_name, kwargs, context_instance=context)
+        return render_to_string(self.template_name,
+                                kwargs,
+                                context_instance=context)
 
     def get_context_data(self):
         return self.context
-
